@@ -32,23 +32,13 @@ public class FileExistsException extends IOException {
     private static final long serialVersionUID = 1L;
 
     /**
-     * Default Constructor.
+     * Constructs a new instance.
      */
     public FileExistsException() {
-        super();
     }
 
     /**
-     * Construct an instance with the specified message.
-     *
-     * @param message The error message
-     */
-    public FileExistsException(final String message) {
-        super(message);
-    }
-
-    /**
-     * Construct an instance with the specified file.
+     * Constructs an instance with the specified file.
      *
      * @param file The file that exists
      */
@@ -56,4 +46,13 @@ public class FileExistsException extends IOException {
         super("File " + file + " exists");
     }
 
+    /**
+     * Constructs an instance with the specified message.
+     *
+     * @param message The error message
+     */
+    public FileExistsException(final String message) {
+        super(message);
+    }
+
 }
