@@ -38,9 +38,9 @@ public class DelegateFileFilter extends AbstractFileFilter implements Serializab
     private static final long serialVersionUID = -8723373124984771318L;
 
     /** The File filter */
-    private transient final FileFilter fileFilter;
+    private final transient FileFilter fileFilter;
     /** The Filename filter */
-    private transient final FilenameFilter fileNameFilter;
+    private final transient FilenameFilter fileNameFilter;
 
     /**
      * Constructs a delegate file filter around an existing FileFilter.
