@@ -49,10 +49,17 @@ public class ObservableInputStream extends ProxyInputStream {
      * @param <T> The subclass.
      * @since 2.18.0
      */
-    public static abstract class AbstractBuilder<T extends AbstractBuilder<T>> extends ProxyInputStream.AbstractBuilder<ObservableInputStream, T> {
+    public abstract static class AbstractBuilder<T extends AbstractBuilder<T>> extends ProxyInputStream.AbstractBuilder<ObservableInputStream, T> {
 
         private List<Observer> observers;
 
+        /**
+         * Constructs a new instance for subclasses.
+         */
+        public AbstractBuilder() {
+            // empty
+        }
+
         /**
          * Sets the list of observer callbacks.
          *
@@ -64,7 +71,6 @@ public class ObservableInputStream extends ProxyInputStream {
 
     }
 
-
     /**
      * Builds instances of {@link ObservableInputStream}.
      *
@@ -72,6 +78,13 @@ public class ObservableInputStream extends ProxyInputStream {
      */
     public static class Builder extends AbstractBuilder<Builder> {
 
+        /**
+         * Constructs a new builder of {@link ObservableInputStream}.
+         */
+        public Builder() {
+            // empty
+        }
+
         @Override
         public ObservableInputStream get() throws IOException {
             return new ObservableInputStream(this);
@@ -82,7 +95,14 @@ public class ObservableInputStream extends ProxyInputStream {
     /**
      * Abstracts observer callback for {@link ObservableInputStream}s.
      */
-    public static abstract class Observer {
+    public abstract static class Observer {
+
+        /**
+         * Constructs a new instance for subclasses.
+         */
+        public Observer() {
+            // empty
+        }
 
         /**
          * Called to indicate that the {@link ObservableInputStream} has been closed.
