@@ -71,16 +71,23 @@ public class ReadAheadInputStream extends FilterInputStream {
 
         private ExecutorService executorService;
 
+        /**
+         * Constructs a new builder of {@link ReadAheadInputStream}.
+         */
+        public Builder() {
+            // empty
+        }
+
         /**
          * Builds a new {@link ReadAheadInputStream}.
          * <p>
-         * You must set input that supports {@link #getInputStream()}, otherwise, this method throws an exception.
+         * You must set an aspect that supports {@link #getInputStream()}, otherwise, this method throws an exception.
          * </p>
          * <p>
-         * This builder use the following aspects:
+         * This builder uses the following aspects:
          * </p>
          * <ul>
-         * <li>{@link #getInputStream()}</li>
+         * <li>{@link #getInputStream()} gets the target aspect.</li>
          * <li>{@link #getBufferSize()}</li>
          * <li>{@link ExecutorService}</li>
          * </ul>
@@ -88,11 +95,11 @@ public class ReadAheadInputStream extends FilterInputStream {
          * @return a new instance.
          * @throws IllegalStateException         if the {@code origin} is {@code null}.
          * @throws UnsupportedOperationException if the origin cannot be converted to an {@link InputStream}.
-         * @throws IOException                   if an I/O error occurs.
+         * @throws IOException                   if an I/O error occurs converting to an {@link InputStream} using {@link #getInputStream()}.
          * @see #getInputStream()
          * @see #getBufferSize()
+         * @see #getUnchecked()
          */
-        @SuppressWarnings("resource")
         @Override
         public ReadAheadInputStream get() throws IOException {
             return new ReadAheadInputStream(getInputStream(), getBufferSize(), executorService != null ? executorService : newExecutorService(),
@@ -407,7 +414,8 @@ public class ReadAheadInputStream extends FilterInputStream {
             //
             // So there is no race condition in both the situations.
             int read = 0;
-            int off = 0, len = arr.length;
+            int off = 0;
+            int len = arr.length;
             Throwable exception = null;
             try {
                 // try to fill the read ahead buffer.
