@@ -45,7 +45,7 @@ import org.apache.commons.io.file.PathUtils;
 import org.apache.commons.io.file.attribute.FileTimes;
 
 /**
- * Simple implementation of the UNIX "tail -f" functionality.
+ * Simple implementation of the Unix "tail -f" functionality.
  * <p>
  * To build an instance, use {@link Builder}.
  * </p>
@@ -188,11 +188,18 @@ public class Tailer implements Runnable, AutoCloseable {
         private boolean startThread = true;
         private ExecutorService executorService = Executors.newSingleThreadExecutor(Builder::newDaemonThread);
 
+        /**
+         * Constructs a new builder of {@link Tailer}.
+         */
+        public Builder() {
+            // empty
+        }
+
         /**
          * Builds a new {@link Tailer}.
          *
          * <p>
-         * This builder use the following aspects:
+         * This builder uses the following aspects:
          * </p>
          * <ul>
          * <li>{@link #getBufferSize()}</li>
@@ -205,6 +212,7 @@ public class Tailer implements Runnable, AutoCloseable {
          * </ul>
          *
          * @return a new instance.
+         * @see #getUnchecked()
          */
         @Override
         public Tailer get() {
@@ -363,7 +371,7 @@ public class Tailer implements Runnable, AutoCloseable {
          * @throws IOException If the first byte cannot be read for any reason other than end of tailable, or if the random
          *         access tailable has been closed, or if some other I/O error occurs.
          */
-        int read(final byte[] b) throws IOException;
+        int read(byte[] b) throws IOException;
 
         /**
          * Sets the file-pointer offset, measured from the beginning of this tailable, at which the next read or write occurs.
@@ -375,7 +383,7 @@ public class Tailer implements Runnable, AutoCloseable {
          *        pointer.
          * @throws IOException if {@code pos} is less than {@code 0} or if an I/O error occurs.
          */
-        void seek(final long pos) throws IOException;
+        void seek(long pos) throws IOException;
     }
 
     /**
@@ -392,7 +400,7 @@ public class Tailer implements Runnable, AutoCloseable {
          * @return a random access file stream to read.
          * @throws FileNotFoundException if the tailable object does not exist.
          */
-        RandomAccessResourceBridge getRandomAccess(final String mode) throws FileNotFoundException;
+        RandomAccessResourceBridge getRandomAccess(String mode) throws FileNotFoundException;
 
         /**
          * Tests if this tailable is newer than the specified {@link FileTime}.
@@ -401,7 +409,7 @@ public class Tailer implements Runnable, AutoCloseable {
          * @return true if the {@link File} exists and has been modified after the given {@link FileTime}.
          * @throws IOException if an I/O error occurs.
          */
-        boolean isNewer(final FileTime fileTime) throws IOException;
+        boolean isNewer(FileTime fileTime) throws IOException;
 
         /**
          * Gets the last modification {@link FileTime}.
@@ -468,7 +476,9 @@ public class Tailer implements Runnable, AutoCloseable {
 
     private static final String RAF_READ_ONLY_MODE = "r";
 
-    // The default charset used for reading files
+    /**
+     * The the virtual machine's {@link Charset#defaultCharset() default charset} used for reading files.
+     */
     private static final Charset DEFAULT_CHARSET = Charset.defaultCharset();
 
     /**
