@@ -123,13 +123,20 @@ public class XmlStreamReader extends Reader {
         private boolean lenient = true;
         private String httpContentType;
 
+        /**
+         * Constructs a new builder of {@link XmlStreamReader}.
+         */
+        public Builder() {
+            // empty
+        }
+
         /**
          * Builds a new {@link XmlStreamWriter}.
          * <p>
-         * You must set input that supports {@link #getInputStream()}, otherwise, this method throws an exception.
+         * You must set an aspect that supports {@link #getInputStream()}, otherwise, this method throws an exception.
          * </p>
          * <p>
-         * This builder use the following aspects:
+         * This builder uses the following aspects:
          * </p>
          * <ul>
          * <li>{@link #getInputStream()}</li>
@@ -141,11 +148,11 @@ public class XmlStreamReader extends Reader {
          * @return a new instance.
          * @throws IllegalStateException         if the {@code origin} is {@code null}.
          * @throws UnsupportedOperationException if the origin cannot be converted to an {@link InputStream}.
-         * @throws IOException                   if an I/O error occurs.
+         * @throws IOException                   if an I/O error occurs converting to an {@link InputStream} using {@link #getInputStream()}.
          * @throws XmlStreamReaderException thrown if the Charset encoding could not be determined according to the specification.
          * @see #getInputStream()
+         * @see #getUnchecked()
          */
-        @SuppressWarnings("resource")
         @Override
         public XmlStreamReader get() throws IOException {
             final String defaultEncoding = nullCharset ? null : getCharset().name();
@@ -694,7 +701,6 @@ public class XmlStreamReader extends Reader {
      * @param xmlEnc          XML encoding
      * @param lenient         indicates if the charset encoding detection should be relaxed.
      * @param httpContentType The HTTP content type
-     *
      * @return the HTTP encoding
      * @throws IOException thrown if there is a problem reading the stream.
      */
