@@ -21,6 +21,7 @@ import java.io.IOException;
 import java.io.OutputStream;
 
 import org.apache.commons.io.IOUtils;
+import org.apache.commons.io.build.AbstractStreamBuilder;
 
 /**
  * A Proxy stream which acts as expected, that is it passes the method
@@ -34,6 +35,47 @@ import org.apache.commons.io.IOUtils;
  */
 public class ProxyOutputStream extends FilterOutputStream {
 
+    /**
+     * Builds instances of {@link ProxyOutputStream}.
+     * <p>
+     * This class does not provide a convenience static {@code builder()} method so that subclasses can.
+     * </p>
+     *
+     * @since 2.19.0
+     */
+    public static class Builder extends AbstractStreamBuilder<ProxyOutputStream, Builder> {
+
+        /**
+         * Constructs a new builder of {@link ProxyOutputStream}.
+         */
+        public Builder() {
+            // empty
+        }
+
+        /**
+         * Builds a new {@link ProxyOutputStream}.
+         * <p>
+         * This builder uses the following aspects:
+         * </p>
+         * <ul>
+         * <li>{@link #getOutputStream()} is the target aspect.</li>
+         * </ul>
+         *
+         * @return a new instance.
+         * @throws IllegalStateException         if the {@code origin} is {@code null}.
+         * @throws UnsupportedOperationException if the origin cannot be converted to an {@link OutputStream}.
+         * @throws IOException                   if an I/O error occurs converting to an {@link OutputStream} using {@link #getOutputStream()}.
+         * @see #getOutputStream()
+         * @see #getUnchecked()
+         */
+        @SuppressWarnings("resource") // caller closes
+        @Override
+        public ProxyOutputStream get() throws IOException {
+            return new ProxyOutputStream(getOutputStream());
+        }
+
+    }
+
     /**
      * Constructs a new ProxyOutputStream.
      *
@@ -54,9 +96,9 @@ public class ProxyOutputStream extends FilterOutputStream {
      * functionality without having to override all the write methods.
      * The default implementation does nothing.
      *
-     * @since 2.0
      * @param n number of bytes written
      * @throws IOException if the post-processing fails
+     * @since 2.0
      */
     @SuppressWarnings("unused") // Possibly thrown from subclasses.
     protected void afterWrite(final int n) throws IOException {
@@ -72,9 +114,9 @@ public class ProxyOutputStream extends FilterOutputStream {
      * functionality without having to override all the write methods.
      * The default implementation does nothing.
      *
-     * @since 2.0
      * @param n number of bytes to be written
      * @throws IOException if the pre-processing fails
+     * @since 2.0
      */
     @SuppressWarnings("unused") // Possibly thrown from subclasses.
     protected void beforeWrite(final int n) throws IOException {
@@ -116,6 +158,30 @@ public class ProxyOutputStream extends FilterOutputStream {
         throw e;
     }
 
+    /**
+     * Sets the underlying output stream.
+     *
+     * @param out the underlying output stream.
+     * @return this instance.
+     * @since 2.19.0
+     */
+    public ProxyOutputStream setReference(final OutputStream out) {
+        this.out = out;
+        return this;
+    }
+
+    /**
+     * Unwraps this instance by returning the underlying {@link OutputStream}.
+     * <p>
+     * Use with caution; useful to query the underlying {@link OutputStream}.
+     * </p>
+     *
+     * @return the underlying {@link OutputStream}.
+     */
+    OutputStream unwrap() {
+        return out;
+    }
+
     /**
      * Invokes the delegate's {@code write(byte[])} method.
      * @param bts the bytes to write
