@@ -20,32 +20,51 @@ import java.io.FilterWriter;
 import java.io.IOException;
 import java.io.Writer;
 
+import org.apache.commons.io.IOUtils;
+
 /**
- * A Proxy stream which acts as expected, that is it passes the method
- * calls on to the proxied stream and doesn't change which methods are
- * being called. It is an alternative base class to FilterWriter
- * to increase reusability, because FilterWriter changes the
- * methods being called, such as write(char[]) to write(char[], int, int)
- * and write(String) to write(String, int, int).
- *
+ * A Proxy stream which acts as expected, that is it passes the method calls on to the proxied stream and doesn't
+ * change which methods are being called. It is an alternative base class to FilterWriter to increase reusability,
+ * because FilterWriter changes the methods being called, such as {@code write(char[]) to write(char[], int, int)}
+ * and {@code write(String) to write(String, int, int)}.
  */
 public class ProxyWriter extends FilterWriter {
 
     /**
      * Constructs a new ProxyWriter.
      *
-     * @param proxy  the Writer to delegate to
+     * @param delegate  the Writer to delegate to
      */
-    public ProxyWriter(final Writer proxy) {
-        super(proxy);
-        // the proxy is stored in a protected superclass variable named 'out'
+    public ProxyWriter(final Writer delegate) {
+        // the delegate is stored in a protected superclass variable named 'out'
+        super(delegate);
     }
 
     /**
-     * Invokes the delegate's <code>append(char)</code> method.
+     * Invoked by the write methods after the proxied call has returned
+     * successfully. The number of chars written (1 for the
+     * {@link #write(int)} method, buffer length for {@link #write(char[])},
+     * etc.) is given as an argument.
+     * <p>
+     * Subclasses can override this method to add common post-processing
+     * functionality without having to override all the write methods.
+     * The default implementation does nothing.
+     * </p>
+     *
+     * @param n number of chars written
+     * @throws IOException if the post-processing fails
+     * @since 2.0
+     */
+    @SuppressWarnings("unused") // Possibly thrown from subclasses.
+    protected void afterWrite(final int n) throws IOException {
+        // noop
+    }
+
+    /**
+     * Invokes the delegate's {@code append(char)} method.
      * @param c The character to write
      * @return this writer
-     * @throws IOException if an I/O error occurs
+     * @throws IOException if an I/O error occurs.
      * @since 2.0
      */
     @Override
@@ -61,12 +80,32 @@ public class ProxyWriter extends FilterWriter {
     }
 
     /**
-     * Invokes the delegate's <code>append(CharSequence, int, int)</code> method.
+     * Invokes the delegate's {@code append(CharSequence)} method.
+     * @param csq The character sequence to write
+     * @return this writer
+     * @throws IOException if an I/O error occurs.
+     * @since 2.0
+     */
+    @Override
+    public Writer append(final CharSequence csq) throws IOException {
+        try {
+            final int len = IOUtils.length(csq);
+            beforeWrite(len);
+            out.append(csq);
+            afterWrite(len);
+        } catch (final IOException e) {
+            handleIOException(e);
+        }
+        return this;
+    }
+
+    /**
+     * Invokes the delegate's {@code append(CharSequence, int, int)} method.
      * @param csq The character sequence to write
      * @param start The index of the first character to write
      * @param end  The index of the first character to write (exclusive)
      * @return this writer
-     * @throws IOException if an I/O error occurs
+     * @throws IOException if an I/O error occurs.
      * @since 2.0
      */
     @Override
@@ -82,126 +121,36 @@ public class ProxyWriter extends FilterWriter {
     }
 
     /**
-     * Invokes the delegate's <code>append(CharSequence)</code> method.
-     * @param csq The character sequence to write
-     * @return this writer
-     * @throws IOException if an I/O error occurs
+     * Invoked by the write methods before the call is proxied. The number
+     * of chars to be written (1 for the {@link #write(int)} method, buffer
+     * length for {@link #write(char[])}, etc.) is given as an argument.
+     * <p>
+     * Subclasses can override this method to add common pre-processing
+     * functionality without having to override all the write methods.
+     * The default implementation does nothing.
+     * </p>
+     *
+     * @param n number of chars to be written
+     * @throws IOException if the pre-processing fails
      * @since 2.0
      */
-    @Override
-    public Writer append(final CharSequence csq) throws IOException {
-        try {
-            int len = 0;
-            if (csq != null) {
-                len = csq.length();
-            }
-
-            beforeWrite(len);
-            out.append(csq);
-            afterWrite(len);
-        } catch (final IOException e) {
-            handleIOException(e);
-        }
-        return this;
+    @SuppressWarnings("unused") // Possibly thrown from subclasses.
+    protected void beforeWrite(final int n) throws IOException {
+        // noop
     }
 
     /**
-     * Invokes the delegate's <code>write(int)</code> method.
-     * @param idx the character to write
-     * @throws IOException if an I/O error occurs
+     * Invokes the delegate's {@code close()} method.
+     * @throws IOException if an I/O error occurs.
      */
     @Override
-    public void write(final int idx) throws IOException {
-        try {
-            beforeWrite(1);
-            out.write(idx);
-            afterWrite(1);
-        } catch (final IOException e) {
-            handleIOException(e);
-        }
+    public void close() throws IOException {
+        IOUtils.close(out, this::handleIOException);
     }
 
     /**
-     * Invokes the delegate's <code>write(char[])</code> method.
-     * @param chr the characters to write
-     * @throws IOException if an I/O error occurs
-     */
-    @Override
-    public void write(final char[] chr) throws IOException {
-        try {
-            int len = 0;
-            if (chr != null) {
-                len = chr.length;
-            }
-
-            beforeWrite(len);
-            out.write(chr);
-            afterWrite(len);
-        } catch (final IOException e) {
-            handleIOException(e);
-        }
-    }
-
-    /**
-     * Invokes the delegate's <code>write(char[], int, int)</code> method.
-     * @param chr the characters to write
-     * @param st The start offset
-     * @param len The number of characters to write
-     * @throws IOException if an I/O error occurs
-     */
-    @Override
-    public void write(final char[] chr, final int st, final int len) throws IOException {
-        try {
-            beforeWrite(len);
-            out.write(chr, st, len);
-            afterWrite(len);
-        } catch (final IOException e) {
-            handleIOException(e);
-        }
-    }
-
-    /**
-     * Invokes the delegate's <code>write(String)</code> method.
-     * @param str the string to write
-     * @throws IOException if an I/O error occurs
-     */
-    @Override
-    public void write(final String str) throws IOException {
-        try {
-            int len = 0;
-            if (str != null) {
-                len = str.length();
-            }
-
-            beforeWrite(len);
-            out.write(str);
-            afterWrite(len);
-        } catch (final IOException e) {
-            handleIOException(e);
-        }
-    }
-
-    /**
-     * Invokes the delegate's <code>write(String)</code> method.
-     * @param str the string to write
-     * @param st The start offset
-     * @param len The number of characters to write
-     * @throws IOException if an I/O error occurs
-     */
-    @Override
-    public void write(final String str, final int st, final int len) throws IOException {
-        try {
-            beforeWrite(len);
-            out.write(str, st, len);
-            afterWrite(len);
-        } catch (final IOException e) {
-            handleIOException(e);
-        }
-    }
-
-    /**
-     * Invokes the delegate's <code>flush()</code> method.
-     * @throws IOException if an I/O error occurs
+     * Invokes the delegate's {@code flush()} method.
+     * @throws IOException if an I/O error occurs.
      */
     @Override
     public void flush() throws IOException {
@@ -213,62 +162,104 @@ public class ProxyWriter extends FilterWriter {
     }
 
     /**
-     * Invokes the delegate's <code>close()</code> method.
-     * @throws IOException if an I/O error occurs
-     */
-    @Override
-    public void close() throws IOException {
-        try {
-            out.close();
-        } catch (final IOException e) {
-            handleIOException(e);
-        }
-    }
-
-    /**
-     * Invoked by the write methods before the call is proxied. The number
-     * of chars to be written (1 for the {@link #write(int)} method, buffer
-     * length for {@link #write(char[])}, etc.) is given as an argument.
-     * <p>
-     * Subclasses can override this method to add common pre-processing
-     * functionality without having to override all the write methods.
-     * The default implementation does nothing.
-     *
-     * @since 2.0
-     * @param n number of chars to be written
-     * @throws IOException if the pre-processing fails
-     */
-    protected void beforeWrite(final int n) throws IOException {
-    }
-
-    /**
-     * Invoked by the write methods after the proxied call has returned
-     * successfully. The number of chars written (1 for the
-     * {@link #write(int)} method, buffer length for {@link #write(char[])},
-     * etc.) is given as an argument.
-     * <p>
-     * Subclasses can override this method to add common post-processing
-     * functionality without having to override all the write methods.
-     * The default implementation does nothing.
-     *
-     * @since 2.0
-     * @param n number of chars written
-     * @throws IOException if the post-processing fails
-     */
-    protected void afterWrite(final int n) throws IOException {
-    }
-
-    /**
-     * Handle any IOExceptions thrown.
+     * Handles any IOExceptions thrown.
      * <p>
      * This method provides a point to implement custom exception
-     * handling. The default behaviour is to re-throw the exception.
+     * handling. The default behavior is to re-throw the exception.
+     * </p>
+     *
      * @param e The IOException thrown
-     * @throws IOException if an I/O error occurs
+     * @throws IOException if an I/O error occurs.
      * @since 2.0
      */
     protected void handleIOException(final IOException e) throws IOException {
         throw e;
     }
 
+    /**
+     * Invokes the delegate's {@code write(char[])} method.
+     * @param cbuf the characters to write
+     * @throws IOException if an I/O error occurs.
+     */
+    @Override
+    public void write(final char[] cbuf) throws IOException {
+        try {
+            final int len = IOUtils.length(cbuf);
+            beforeWrite(len);
+            out.write(cbuf);
+            afterWrite(len);
+        } catch (final IOException e) {
+            handleIOException(e);
+        }
+    }
+
+    /**
+     * Invokes the delegate's {@code write(char[], int, int)} method.
+     * @param cbuf the characters to write
+     * @param off The start offset
+     * @param len The number of characters to write
+     * @throws IOException if an I/O error occurs.
+     */
+    @Override
+    public void write(final char[] cbuf, final int off, final int len) throws IOException {
+        try {
+            beforeWrite(len);
+            out.write(cbuf, off, len);
+            afterWrite(len);
+        } catch (final IOException e) {
+            handleIOException(e);
+        }
+    }
+
+    /**
+     * Invokes the delegate's {@code write(int)} method.
+     * @param c the character to write
+     * @throws IOException if an I/O error occurs.
+     */
+    @Override
+    public void write(final int c) throws IOException {
+        try {
+            beforeWrite(1);
+            out.write(c);
+            afterWrite(1);
+        } catch (final IOException e) {
+            handleIOException(e);
+        }
+    }
+
+    /**
+     * Invokes the delegate's {@code write(String)} method.
+     * @param str the string to write
+     * @throws IOException if an I/O error occurs.
+     */
+    @Override
+    public void write(final String str) throws IOException {
+        try {
+            final int len = IOUtils.length(str);
+            beforeWrite(len);
+            out.write(str);
+            afterWrite(len);
+        } catch (final IOException e) {
+            handleIOException(e);
+        }
+    }
+
+    /**
+     * Invokes the delegate's {@code write(String)} method.
+     * @param str the string to write
+     * @param off The start offset
+     * @param len The number of characters to write
+     * @throws IOException if an I/O error occurs.
+     */
+    @Override
+    public void write(final String str, final int off, final int len) throws IOException {
+        try {
+            beforeWrite(len);
+            out.write(str, off, len);
+            afterWrite(len);
+        } catch (final IOException e) {
+            handleIOException(e);
+        }
+    }
+
 }
