@@ -45,6 +45,7 @@ import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.OutputStream;
 import java.io.Reader;
+import java.io.SequenceInputStream;
 import java.io.StringReader;
 import java.io.Writer;
 import java.net.ServerSocket;
@@ -60,7 +61,10 @@ import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.List;
+import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.function.Consumer;
 import java.util.function.Supplier;
 import java.util.stream.Stream;
 
@@ -79,6 +83,7 @@ import org.apache.commons.io.output.StringBuilderWriter;
 import org.apache.commons.io.test.TestUtils;
 import org.apache.commons.io.test.ThrowOnCloseReader;
 import org.apache.commons.lang3.StringUtils;
+import org.apache.commons.lang3.exception.ExceptionUtils;
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.BeforeEach;
@@ -319,28 +324,43 @@ public class IOUtilsTest {
 
     @Test
     public void testCloseConsumer() {
+        // null consumer
         final Closeable nullCloseable = null;
-        assertDoesNotThrow(() -> IOUtils.close(nullCloseable, null)); // null consumer
-        assertDoesNotThrow(() -> IOUtils.close(new StringReader("s"), null)); // null consumer
-        assertDoesNotThrow(() -> IOUtils.close(new ThrowOnCloseReader(new StringReader("s")), null)); // null consumer
-
-        final IOConsumer<IOException> nullConsumer = null; // null consumer doesn't throw
+        assertDoesNotThrow(() -> IOUtils.close(nullCloseable, null));
+        assertDoesNotThrow(() -> IOUtils.close(new StringReader("s"), null));
+        assertDoesNotThrow(() -> IOUtils.close(new ThrowOnCloseReader(new StringReader("s")), null));
+        // null consumer doesn't throw
+        final IOConsumer<IOException> nullConsumer = null;
         assertDoesNotThrow(() -> IOUtils.close(nullCloseable, nullConsumer));
         assertDoesNotThrow(() -> IOUtils.close(new StringReader("s"), nullConsumer));
         assertDoesNotThrow(() -> IOUtils.close(new ThrowOnCloseReader(new StringReader("s")), nullConsumer));
-
-        final IOConsumer<IOException> silentConsumer = IOConsumer.noop(); // noop consumer doesn't throw
+        // noop consumer doesn't throw
+        final IOConsumer<IOException> silentConsumer = IOConsumer.noop();
         assertDoesNotThrow(() -> IOUtils.close(nullCloseable, silentConsumer));
         assertDoesNotThrow(() -> IOUtils.close(new StringReader("s"), silentConsumer));
         assertDoesNotThrow(() -> IOUtils.close(new ThrowOnCloseReader(new StringReader("s")), silentConsumer));
-
-        final IOConsumer<IOException> noisyConsumer = i -> {
-            throw i;
-        }; // consumer passes on the throw
-        assertDoesNotThrow(() -> IOUtils.close(nullCloseable, noisyConsumer)); // no throw
-        assertDoesNotThrow(() -> IOUtils.close(new StringReader("s"), noisyConsumer)); // no throw
-        assertThrows(IOException.class,
-            () -> IOUtils.close(new ThrowOnCloseReader(new StringReader("s")), noisyConsumer)); // closeable throws
+        // consumer passes on the throw
+        final IOConsumer<IOException> noisyConsumer = ExceptionUtils::rethrow;
+        // no throw
+        assertDoesNotThrow(() -> IOUtils.close(nullCloseable, noisyConsumer));
+        // no throw
+        assertDoesNotThrow(() -> IOUtils.close(new StringReader("s"), noisyConsumer));
+        // closeable throws
+        assertThrows(IOException.class, () -> IOUtils.close(new ThrowOnCloseReader(new StringReader("s")), noisyConsumer));
+        // consumes other than IOException
+        final AtomicBoolean b = new AtomicBoolean();
+        final IOConsumer<IOException> consumer = e -> b.set(true);
+        // IOException subclass
+        assertDoesNotThrow(() -> IOUtils.close(new BrokenOutputStream((Throwable) new EOFException()), consumer));
+        assertTrue(b.get());
+        b.set(false);
+        // RuntimeException
+        assertDoesNotThrow(() -> IOUtils.close(new BrokenOutputStream(new RuntimeException()), consumer));
+        assertTrue(b.get());
+        b.set(false);
+        // RuntimeException subclass
+        assertDoesNotThrow(() -> IOUtils.close(new BrokenOutputStream(new UnsupportedOperationException()), consumer));
+        assertTrue(b.get());
     }
 
     @Test
@@ -364,13 +384,40 @@ public class IOUtilsTest {
     }
 
     @Test
-    public void testCloseQuietly_CloseableIOException() {
-        assertDoesNotThrow(() -> {
-            IOUtils.closeQuietly(BrokenInputStream.INSTANCE);
-        });
-        assertDoesNotThrow(() -> {
-            IOUtils.closeQuietly(BrokenOutputStream.INSTANCE);
-        });
+    public void testCloseQuietly_CloseableException() {
+        // IOException
+        assertDoesNotThrow(() -> IOUtils.closeQuietly(BrokenInputStream.INSTANCE));
+        assertDoesNotThrow(() -> IOUtils.closeQuietly(BrokenOutputStream.INSTANCE));
+        // IOException subclass
+        assertDoesNotThrow(() -> IOUtils.closeQuietly(new BrokenOutputStream((Throwable) new EOFException())));
+        // RuntimeException
+        assertDoesNotThrow(() -> IOUtils.closeQuietly(new BrokenOutputStream(new RuntimeException())));
+        // RuntimeException subclass
+        assertDoesNotThrow(() -> IOUtils.closeQuietly(new BrokenOutputStream(new UnsupportedOperationException())));
+    }
+
+    @Test
+    public void testCloseQuietly_CloseableExceptionConsumer() {
+        final AtomicBoolean b = new AtomicBoolean();
+        final Consumer<Exception> consumer = e -> b.set(true);
+        // IOException
+        assertDoesNotThrow(() -> IOUtils.closeQuietly(BrokenInputStream.INSTANCE, consumer));
+        assertTrue(b.get());
+        b.set(false);
+        assertDoesNotThrow(() -> IOUtils.closeQuietly(BrokenOutputStream.INSTANCE, consumer));
+        assertTrue(b.get());
+        b.set(false);
+        // IOException subclass
+        assertDoesNotThrow(() -> IOUtils.closeQuietly(new BrokenOutputStream((Throwable) new EOFException()), consumer));
+        assertTrue(b.get());
+        b.set(false);
+        // RuntimeException
+        assertDoesNotThrow(() -> IOUtils.closeQuietly(new BrokenOutputStream(new RuntimeException()), consumer));
+        assertTrue(b.get());
+        b.set(false);
+        // RuntimeException subclass
+        assertDoesNotThrow(() -> IOUtils.closeQuietly(new BrokenOutputStream(new UnsupportedOperationException()), consumer));
+        assertTrue(b.get());
     }
 
     @SuppressWarnings("squid:S2699") // Suppress "Add at least one assertion to this test case"
@@ -558,9 +605,9 @@ public class IOUtilsTest {
             new ByteArrayInputStream(bytes2XDefaultA)));
         // FileInputStream a bit more than 16 k.
         try (
-            final FileInputStream input1 = new FileInputStream(
+            FileInputStream input1 = new FileInputStream(
                 "src/test/resources/org/apache/commons/io/abitmorethan16k.txt");
-            final FileInputStream input2 = new FileInputStream(
+            FileInputStream input2 = new FileInputStream(
                 "src/test/resources/org/apache/commons/io/abitmorethan16kcopy.txt")) {
             assertTrue(IOUtils.contentEquals(input1, input1));
         }
@@ -644,6 +691,83 @@ public class IOUtilsTest {
         testSingleEOL("1235", "1234", false);
     }
 
+    @Test
+    public void testContentEqualsSequenceInputStream() throws Exception {
+        // https://issues.apache.org/jira/browse/IO-866
+        // not equals
+        // @formatter:off
+        assertFalse(IOUtils.contentEquals(
+                new ByteArrayInputStream("ab".getBytes()),
+                new SequenceInputStream(
+                    new ByteArrayInputStream("a".getBytes()),
+                    new ByteArrayInputStream("b-".getBytes()))));
+        assertFalse(IOUtils.contentEquals(
+                new ByteArrayInputStream("ab".getBytes()),
+                new SequenceInputStream(
+                    new ByteArrayInputStream("a-".getBytes()),
+                    new ByteArrayInputStream("b".getBytes()))));
+        assertFalse(IOUtils.contentEquals(
+                new ByteArrayInputStream("ab-".getBytes()),
+                new SequenceInputStream(
+                    new ByteArrayInputStream("a".getBytes()),
+                    new ByteArrayInputStream("b".getBytes()))));
+        assertFalse(IOUtils.contentEquals(
+                new ByteArrayInputStream("".getBytes()),
+                new SequenceInputStream(
+                    new ByteArrayInputStream("a".getBytes()),
+                    new ByteArrayInputStream("b".getBytes()))));
+        assertFalse(IOUtils.contentEquals(
+                new ByteArrayInputStream("".getBytes()),
+                new SequenceInputStream(
+                    new ByteArrayInputStream("".getBytes()),
+                    new ByteArrayInputStream("b".getBytes()))));
+        assertFalse(IOUtils.contentEquals(
+                new ByteArrayInputStream("ab".getBytes()),
+                new SequenceInputStream(
+                    new ByteArrayInputStream("".getBytes()),
+                    new ByteArrayInputStream("".getBytes()))));
+        // equals
+        assertTrue(IOUtils.contentEquals(
+                new ByteArrayInputStream("".getBytes()),
+                new SequenceInputStream(
+                    new ByteArrayInputStream("".getBytes()),
+                    new ByteArrayInputStream("".getBytes()))));
+        assertTrue(IOUtils.contentEquals(
+                new ByteArrayInputStream("ab".getBytes()),
+                new SequenceInputStream(
+                    new ByteArrayInputStream("a".getBytes()),
+                    new ByteArrayInputStream("b".getBytes()))));
+        assertTrue(IOUtils.contentEquals(
+                new ByteArrayInputStream("ab".getBytes()),
+                new SequenceInputStream(
+                    new ByteArrayInputStream("ab".getBytes()),
+                    new ByteArrayInputStream("".getBytes()))));
+        assertTrue(IOUtils.contentEquals(
+                new ByteArrayInputStream("ab".getBytes()),
+                new SequenceInputStream(
+                    new ByteArrayInputStream("".getBytes()),
+                    new ByteArrayInputStream("ab".getBytes()))));
+        // @formatter:on
+        final byte[] prefixLen32 = { 1, 2, 3, 4, 5, 6, 7, 8, 9, 9, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 0, 1, 2 };
+        final byte[] suffixLen2 = { 1, 2 };
+        final byte[] fileContents = "someTexts".getBytes(StandardCharsets.UTF_8);
+        Files.write(testFile.toPath(), fileContents);
+        final byte[] expected = new byte[prefixLen32.length + fileContents.length + suffixLen2.length];
+        System.arraycopy(prefixLen32, 0, expected, 0, prefixLen32.length);
+        System.arraycopy(fileContents, 0, expected, prefixLen32.length, fileContents.length);
+        System.arraycopy(suffixLen2, 0, expected, prefixLen32.length + fileContents.length, suffixLen2.length);
+        // @formatter:off
+        assertTrue(IOUtils.contentEquals(
+                new ByteArrayInputStream(expected),
+                new SequenceInputStream(
+                    Collections.enumeration(
+                        Arrays.asList(
+                            new ByteArrayInputStream(prefixLen32),
+                            new FileInputStream(testFile),
+                            new ByteArrayInputStream(suffixLen2))))));
+        // @formatter:on
+    }
+
     @Test
     public void testCopy_ByteArray_OutputStream() throws Exception {
         final File destination = TestUtils.newFile(temporaryFolder, "copy8.txt");
@@ -1020,8 +1144,8 @@ public class IOUtilsTest {
         final File file = TestUtils.newFile(temporaryFolder, "lines.txt");
         CharSequence csq = null;
         try {
-            final String[] data = {"hello", "/u1234", "", "this is", "some text"};
-            TestUtils.createLineBasedFile(file, data);
+            final String[] data = {"hello", "\u1234", "", "this is", "some text"};
+            TestUtils.createLineFileUtf8(file, data);
             csq = new String(Files.readAllBytes(file.toPath()), StandardCharsets.UTF_8);
             final List<String> lines = IOUtils.readLines(csq);
             assertEquals(Arrays.asList(data), lines);
@@ -1035,8 +1159,8 @@ public class IOUtilsTest {
         final File file = TestUtils.newFile(temporaryFolder, "lines.txt");
         StringBuilder csq = null;
         try {
-            final String[] data = {"hello", "/u1234", "", "this is", "some text"};
-            TestUtils.createLineBasedFile(file, data);
+            final String[] data = {"hello", "\u1234", "", "this is", "some text"};
+            TestUtils.createLineFileUtf8(file, data);
             csq = new StringBuilder(new String(Files.readAllBytes(file.toPath()), StandardCharsets.UTF_8));
             final List<String> lines = IOUtils.readLines(csq);
             assertEquals(Arrays.asList(data), lines);
@@ -1051,7 +1175,7 @@ public class IOUtilsTest {
         InputStream in = null;
         try {
             final String[] data = {"hello", "world", "", "this is", "some text"};
-            TestUtils.createLineBasedFile(file, data);
+            TestUtils.createLineFileUtf8(file, data);
 
             in = Files.newInputStream(file.toPath());
             final List<String> lines = IOUtils.readLines(in);
@@ -1068,9 +1192,8 @@ public class IOUtilsTest {
         final File file = TestUtils.newFile(temporaryFolder, "lines.txt");
         InputStream in = null;
         try {
-            final String[] data = {"hello", "/u1234", "", "this is", "some text"};
-            TestUtils.createLineBasedFile(file, data);
-
+            final String[] data = { "\u4f60\u597d", "hello", "\u1234", "", "this is", "some text" };
+            TestUtils.createLineFileUtf8(file, data);
             in = Files.newInputStream(file.toPath());
             final List<String> lines = IOUtils.readLines(in, UTF_8);
             assertEquals(Arrays.asList(data), lines);
@@ -1086,8 +1209,9 @@ public class IOUtilsTest {
         final File file = TestUtils.newFile(temporaryFolder, "lines.txt");
         Reader in = null;
         try {
-            final String[] data = {"hello", "/u1234", "", "this is", "some text"};
-            TestUtils.createLineBasedFile(file, data);
+            // Don't use non-ASCII in this test fixture because this test uses the default platform encoding.
+            final String[] data = {"hello", "1234", "", "this is", "some text"};
+            TestUtils.createLineFileUtf8(file, data);
             in = new InputStreamReader(Files.newInputStream(file.toPath()));
             final List<String> lines = IOUtils.readLines(in);
             assertEquals(Arrays.asList(data), lines);
@@ -1337,7 +1461,7 @@ public class IOUtilsTest {
     public void testSkipFully_InputStream() throws Exception {
         final int size = 1027;
 
-        try (final InputStream input = new ByteArrayInputStream(new byte[size])) {
+        try (InputStream input = new ByteArrayInputStream(new byte[size])) {
             assertThrows(IllegalArgumentException.class, () -> IOUtils.skipFully(input, -1), "Should have failed with IllegalArgumentException");
 
             IOUtils.skipFully(input, 0);
@@ -1350,7 +1474,7 @@ public class IOUtilsTest {
     public void testSkipFully_InputStream_Buffer_New_bytes() throws Exception {
         final int size = 1027;
         final Supplier<byte[]> bas = () -> new byte[size];
-        try (final InputStream input = new ByteArrayInputStream(new byte[size])) {
+        try (InputStream input = new ByteArrayInputStream(new byte[size])) {
             assertThrows(IllegalArgumentException.class, () -> IOUtils.skipFully(input, -1, bas), "Should have failed with IllegalArgumentException");
 
             IOUtils.skipFully(input, 0, bas);
@@ -1364,7 +1488,7 @@ public class IOUtilsTest {
         final int size = 1027;
         final byte[] ba = new byte[size];
         final Supplier<byte[]> bas = () -> ba;
-        try (final InputStream input = new ByteArrayInputStream(new byte[size])) {
+        try (InputStream input = new ByteArrayInputStream(new byte[size])) {
             assertThrows(IllegalArgumentException.class, () -> IOUtils.skipFully(input, -1, bas), "Should have failed with IllegalArgumentException");
 
             IOUtils.skipFully(input, 0, bas);
@@ -1377,7 +1501,7 @@ public class IOUtilsTest {
     public void testSkipFully_InputStream_Buffer_Reuse_ThreadLocal() throws Exception {
         final int size = 1027;
         final ThreadLocal<byte[]> tl = ThreadLocal.withInitial(() -> new byte[size]);
-        try (final InputStream input = new ByteArrayInputStream(new byte[size])) {
+        try (InputStream input = new ByteArrayInputStream(new byte[size])) {
             assertThrows(IllegalArgumentException.class, () -> IOUtils.skipFully(input, -1, tl::get), "Should have failed with IllegalArgumentException");
 
             IOUtils.skipFully(input, 0, tl::get);
@@ -1403,7 +1527,7 @@ public class IOUtilsTest {
     @Test
     public void testSkipFully_Reader() throws Exception {
         final int size = 1027;
-        try (final Reader input = new CharArrayReader(new char[size])) {
+        try (Reader input = new CharArrayReader(new char[size])) {
             IOUtils.skipFully(input, 0);
             IOUtils.skipFully(input, size - 3);
             assertThrows(IllegalArgumentException.class, () -> IOUtils.skipFully(input, -1), "Should have failed with IllegalArgumentException");
@@ -1528,7 +1652,7 @@ public class IOUtilsTest {
 
     @Test
     public void testToByteArray_InputStream_SizeZero() throws Exception {
-        try (InputStream fin =Files.newInputStream(testFilePath)) {
+        try (InputStream fin = Files.newInputStream(testFilePath)) {
             final byte[] out = IOUtils.toByteArray(fin, 0);
             assertNotNull(out, "Out cannot be null");
             assertEquals(0, out.length, "Out length must be 0");
