@@ -16,34 +16,30 @@
  */
 package org.apache.commons.io.comparator;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.BufferedOutputStream;
 import java.io.File;
-import java.io.FileOutputStream;
 import java.io.IOException;
+import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.Comparator;
 import java.util.List;
 
-import org.apache.commons.io.testtools.TestUtils;
-import org.junit.Before;
-import org.junit.Test;
+import org.apache.commons.io.test.TestUtils;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
- * Test case for {@link CompositeFileComparator}.
+ * Tests {@link CompositeFileComparator}.
  */
-public class CompositeFileComparatorTest extends ComparatorAbstractTestCase {
+public class CompositeFileComparatorTest extends ComparatorAbstractTest {
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
-        comparator = new CompositeFileComparator(
-                new AbstractFileComparator[] {
-                    (AbstractFileComparator) SizeFileComparator.SIZE_COMPARATOR,
-                    (AbstractFileComparator) ExtensionFileComparator.EXTENSION_COMPARATOR});
-        reverse = new ReverseComparator(comparator);
-        final File dir = getTestDirectory();
+        comparator = new CompositeFileComparator(SizeFileComparator.SIZE_COMPARATOR, ExtensionFileComparator.EXTENSION_COMPARATOR);
+        reverse = new ReverseFileComparator(comparator);
         lessFile   = new File(dir, "xyz.txt");
         equalFile1 = new File(dir, "foo.txt");
         equalFile2 = new File(dir, "bar.txt");
@@ -53,70 +49,70 @@ public class CompositeFileComparatorTest extends ComparatorAbstractTestCase {
                     + " as the parent directory does not exist");
         }
 
-        try (final BufferedOutputStream output3 =
-                new BufferedOutputStream(new FileOutputStream(lessFile))) {
+        try (BufferedOutputStream output3 =
+                new BufferedOutputStream(Files.newOutputStream(lessFile.toPath()))) {
             TestUtils.generateTestData(output3, 32);
         }
         if (!equalFile1.getParentFile().exists()) {
             throw new IOException("Cannot create file " + equalFile1
                     + " as the parent directory does not exist");
         }
-        try (final BufferedOutputStream output2 =
-                new BufferedOutputStream(new FileOutputStream(equalFile1))) {
+        try (BufferedOutputStream output2 =
+                new BufferedOutputStream(Files.newOutputStream(equalFile1.toPath()))) {
             TestUtils.generateTestData(output2, 48);
         }
         if (!equalFile2.getParentFile().exists()) {
             throw new IOException("Cannot create file " + equalFile2
                     + " as the parent directory does not exist");
         }
-        try (final BufferedOutputStream output1 =
-                new BufferedOutputStream(new FileOutputStream(equalFile2))) {
+        try (BufferedOutputStream output1 =
+                new BufferedOutputStream(Files.newOutputStream(equalFile2.toPath()))) {
             TestUtils.generateTestData(output1, 48);
         }
         if (!moreFile.getParentFile().exists()) {
             throw new IOException("Cannot create file " + moreFile
                     + " as the parent directory does not exist");
         }
-        try (final BufferedOutputStream output =
-                new BufferedOutputStream(new FileOutputStream(moreFile))) {
+        try (BufferedOutputStream output =
+                new BufferedOutputStream(Files.newOutputStream(moreFile.toPath()))) {
             TestUtils.generateTestData(output, 48);
         }
     }
 
-    /**
-     * Test Constructor with null Iterable
-     */
-    @Test
-    public void constructorIterable_order() {
-        final List<Comparator<File>> list = new ArrayList<>();
-        list.add(SizeFileComparator.SIZE_COMPARATOR);
-        list.add(ExtensionFileComparator.EXTENSION_COMPARATOR);
-        final Comparator<File> c = new CompositeFileComparator(list);
-
-        assertEquals("equal", 0, c.compare(equalFile1, equalFile2));
-        assertTrue("less",  c.compare(lessFile, moreFile) < 0);
-        assertTrue("more",  c.compare(moreFile, lessFile) > 0);
-    }
-
-    /**
-     * Test Constructor with null Iterable
-     */
-    @Test
-    public void constructorIterable_Null() {
-        final Comparator<File> c = new CompositeFileComparator((Iterable<Comparator<File>>)null);
-        assertEquals("less,more", 0, c.compare(lessFile, moreFile));
-        assertEquals("more,less", 0, c.compare(moreFile, lessFile));
-        assertEquals("toString", "CompositeFileComparator{}", c.toString());
-    }
-
     /**
      * Test Constructor with null array
      */
     @Test
-    public void constructorArray_Null() {
-        final Comparator<File> c = new CompositeFileComparator((Comparator<File>[])null);
-        assertEquals("less,more", 0, c.compare(lessFile, moreFile));
-        assertEquals("more,less", 0, c.compare(moreFile, lessFile));
-        assertEquals("toString", "CompositeFileComparator{}", c.toString());
+    public void testConstructorArray_Null() {
+        final Comparator<File> c = new CompositeFileComparator((Comparator<File>[]) null);
+        assertEquals(0, c.compare(lessFile, moreFile), "less,more");
+        assertEquals(0, c.compare(moreFile, lessFile), "more,less");
+        assertEquals("CompositeFileComparator{}", c.toString(), "toString");
+    }
+
+    /**
+     * Test Constructor with null Iterable
+     */
+    @Test
+    public void testConstructorIterable_Null() {
+        final Comparator<File> c = new CompositeFileComparator((Iterable<Comparator<File>>) null);
+        assertEquals(0, c.compare(lessFile, moreFile), "less,more");
+        assertEquals(0, c.compare(moreFile, lessFile), "more,less");
+        assertEquals("CompositeFileComparator{}", c.toString(), "toString");
+    }
+
+    /**
+     * Test Constructor with null Iterable
+     */
+    @Test
+    public void testConstructorIterable_order() {
+        final List<Comparator<File>> list = new ArrayList<>();
+        list.add(SizeFileComparator.SIZE_COMPARATOR);
+        list.add(ExtensionFileComparator.EXTENSION_COMPARATOR);
+        final Comparator<File> c = new CompositeFileComparator(list);
+
+        assertEquals(0, c.compare(equalFile1, equalFile2), "equal");
+        assertTrue(c.compare(lessFile, moreFile) < 0, "less");
+        assertTrue(c.compare(moreFile, lessFile) > 0, "more");
     }
 }
