@@ -18,15 +18,15 @@ package org.apache.commons.io.comparator;
 
 import java.io.File;
 
-import org.junit.Before;
+import org.junit.jupiter.api.BeforeEach;
 
 /**
- * Test case for {@link DefaultFileComparator}.
+ * Tests {@link DefaultFileComparator}.
  */
-public class DefaultFileComparatorTest extends ComparatorAbstractTestCase {
+public class DefaultFileComparatorTest extends ComparatorAbstractTest {
 
-    @Before
-    public void setUp() throws Exception {
+    @BeforeEach
+    public void setUp() {
         comparator = (AbstractFileComparator) DefaultFileComparator.DEFAULT_COMPARATOR;
         reverse = DefaultFileComparator.DEFAULT_REVERSE;
         equalFile1 = new File("foo");
