@@ -16,22 +16,22 @@
  */
 package org.apache.commons.io.comparator;
 
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.File;
 import java.util.Comparator;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
- * Test case for {@link PathFileComparator}.
+ * Tests {@link PathFileComparator}.
  */
-public class PathFileComparatorTest extends ComparatorAbstractTestCase {
+public class PathFileComparatorTest extends ComparatorAbstractTest {
 
-
-    @Before
-    public void setUp() throws Exception {
+    @BeforeEach
+    public void setUp() {
         comparator = (AbstractFileComparator) PathFileComparator.PATH_COMPARATOR;
         reverse = PathFileComparator.PATH_REVERSE;
         equalFile1 = new File("foo/file.txt");
@@ -45,14 +45,14 @@ public class PathFileComparatorTest extends ComparatorAbstractTestCase {
     public void testCaseSensitivity() {
         final File file3 = new File("FOO/file.txt");
         final Comparator<File> sensitive = new PathFileComparator(null); /* test null as well */
-        assertTrue("sensitive file1 & file2 = 0", sensitive.compare(equalFile1, equalFile2) == 0);
-        assertTrue("sensitive file1 & file3 > 0", sensitive.compare(equalFile1, file3) > 0);
-        assertTrue("sensitive file1 & less  > 0", sensitive.compare(equalFile1, lessFile) > 0);
+        assertEquals(0, sensitive.compare(equalFile1, equalFile2), "sensitive file1 & file2 = 0");
+        assertTrue(sensitive.compare(equalFile1, file3) > 0, "sensitive file1 & file3 > 0");
+        assertTrue(sensitive.compare(equalFile1, lessFile) > 0, "sensitive file1 & less  > 0");
 
         final Comparator<File> insensitive = PathFileComparator.PATH_INSENSITIVE_COMPARATOR;
-        assertTrue("insensitive file1 & file2 = 0", insensitive.compare(equalFile1, equalFile2) == 0);
-        assertTrue("insensitive file1 & file3 = 0", insensitive.compare(equalFile1, file3) == 0);
-        assertTrue("insensitive file1 & file4 > 0", insensitive.compare(equalFile1, lessFile) > 0);
-        assertTrue("insensitive file3 & less  > 0", insensitive.compare(file3, lessFile) > 0);
+        assertEquals(0, insensitive.compare(equalFile1, equalFile2), "insensitive file1 & file2 = 0");
+        assertEquals(0, insensitive.compare(equalFile1, file3), "insensitive file1 & file3 = 0");
+        assertTrue(insensitive.compare(equalFile1, lessFile) > 0, "insensitive file1 & file4 > 0");
+        assertTrue(insensitive.compare(file3, lessFile) > 0, "insensitive file3 & less  > 0");
     }
 }
