@@ -16,35 +16,34 @@
  */
 package org.apache.commons.io.comparator;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.BufferedOutputStream;
 import java.io.File;
-import java.io.FileOutputStream;
 import java.io.IOException;
+import java.nio.file.Files;
 
-import org.apache.commons.io.testtools.TestUtils;
-import org.junit.Before;
-import org.junit.Test;
+import org.apache.commons.io.FileUtils;
+import org.apache.commons.io.test.TestUtils;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 /**
- * Test case for {@link SizeFileComparator}.
+ * Tests {@link SizeFileComparator}.
  */
-public class SizeFileComparatorTest extends ComparatorAbstractTestCase {
+public class SizeFileComparatorTest extends ComparatorAbstractTest {
 
     private File smallerDir;
     private File largerDir;
     private File smallerFile;
     private File largerFile;
 
-    /** @see junit.framework.TestCase#setUp() */
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         comparator = (AbstractFileComparator) SizeFileComparator.SIZE_COMPARATOR;
         reverse = SizeFileComparator.SIZE_REVERSE;
-        final File dir = getTestDirectory();
         smallerDir = new File(dir, "smallerdir");
         largerDir = new File(dir, "largerdir");
         smallerFile = new File(smallerDir, "smaller.txt");
@@ -56,24 +55,24 @@ public class SizeFileComparatorTest extends ComparatorAbstractTestCase {
             throw new IOException("Cannot create file " + smallerFile
                     + " as the parent directory does not exist");
         }
-        try (final BufferedOutputStream output2 =
-                new BufferedOutputStream(new FileOutputStream(smallerFile))) {
+        try (BufferedOutputStream output2 =
+                new BufferedOutputStream(Files.newOutputStream(smallerFile.toPath()))) {
             TestUtils.generateTestData(output2, 32);
         }
         if (!equalFile.getParentFile().exists()) {
             throw new IOException("Cannot create file " + equalFile
                     + " as the parent directory does not exist");
         }
-        try (final BufferedOutputStream output1 =
-                new BufferedOutputStream(new FileOutputStream(equalFile))) {
+        try (BufferedOutputStream output1 =
+                new BufferedOutputStream(Files.newOutputStream(equalFile.toPath()))) {
             TestUtils.generateTestData(output1, 48);
         }
         if (!largerFile.getParentFile().exists()) {
             throw new IOException("Cannot create file " + largerFile
                     + " as the parent directory does not exist");
         }
-        try (final BufferedOutputStream output =
-                new BufferedOutputStream(new FileOutputStream(largerFile))) {
+        try (BufferedOutputStream output =
+                new BufferedOutputStream(Files.newOutputStream(largerFile.toPath()))) {
             TestUtils.generateTestData(output, 64);
         }
         equalFile1 = equalFile;
@@ -86,19 +85,19 @@ public class SizeFileComparatorTest extends ComparatorAbstractTestCase {
      * Test a file which doesn't exist.
      */
     @Test
-    public void testNonexistantFile() {
-        final File nonexistantFile = new File(new File("."), "nonexistant.txt");
-        assertFalse(nonexistantFile.exists());
-        assertTrue("less",  comparator.compare(nonexistantFile, moreFile) < 0);
+    public void testCompareDirectorySizes() {
+        assertEquals(0, comparator.compare(smallerDir, largerDir), "sumDirectoryContents=false");
+        assertEquals(-1, SizeFileComparator.SIZE_SUMDIR_COMPARATOR.compare(smallerDir, largerDir), "less");
+        assertEquals(1, SizeFileComparator.SIZE_SUMDIR_REVERSE.compare(smallerDir, largerDir), "less");
     }
 
     /**
      * Test a file which doesn't exist.
      */
     @Test
-    public void testCompareDirectorySizes() {
-        assertEquals("sumDirectoryContents=false", 0, comparator.compare(smallerDir, largerDir));
-        assertEquals("less", -1, SizeFileComparator.SIZE_SUMDIR_COMPARATOR.compare(smallerDir, largerDir));
-        assertEquals("less", 1,  SizeFileComparator.SIZE_SUMDIR_REVERSE.compare(smallerDir, largerDir));
+    public void testNonExistentFile() {
+        final File nonExistentFile = new File(FileUtils.current(), "non-existent.txt");
+        assertFalse(nonExistentFile.exists());
+        assertTrue(comparator.compare(nonExistentFile, moreFile) < 0, "less");
     }
 }
