@@ -138,7 +138,7 @@ public class PathUtilsTest extends AbstractTempDirTest {
     public void testCopyDirectoryForDifferentFilesystemsWithRelativePath() throws IOException {
         final Path archivePath = Paths.get(TEST_JAR_PATH);
         try (FileSystem archive = openArchive(archivePath, false);
-                final FileSystem targetArchive = openArchive(tempDirPath.resolve(TEST_JAR_NAME), true)) {
+                FileSystem targetArchive = openArchive(tempDirPath.resolve(TEST_JAR_NAME), true)) {
             final Path targetDir = targetArchive.getPath("targetDir");
             Files.createDirectory(targetDir);
             // relative jar -> relative dir
@@ -178,6 +178,16 @@ public class PathUtilsTest extends AbstractTempDirTest {
         assertEquals(Files.size(sourceFile), Files.size(targetFile));
     }
 
+    @Test
+    public void testCopyFileTwoFileSystem() throws IOException {
+        try (FileSystem archive = openArchive(Paths.get(TEST_JAR_PATH), false)) {
+            final Path sourceFile = archive.getPath("next/dir/test.log");
+            final Path targetFile = PathUtils.copyFileToDirectory(sourceFile, tempDirPath);
+            assertTrue(Files.exists(targetFile));
+            assertEquals(Files.size(sourceFile), Files.size(targetFile));
+        }
+    }
+
     @Test
     public void testCopyURL() throws IOException {
         final Path sourceFile = Paths.get("src/test/resources/org/apache/commons/io/dirs-1-file-size-1/file-size-1.bin");
@@ -574,8 +584,8 @@ public class PathUtilsTest extends AbstractTempDirTest {
     @Test
     public void testWriteStringToFile1() throws Exception {
         final Path file = tempDirPath.resolve("write.txt");
-        PathUtils.writeString(file, "Hello /u1234", StandardCharsets.UTF_8);
-        final byte[] text = "Hello /u1234".getBytes(StandardCharsets.UTF_8);
+        PathUtils.writeString(file, "Hello \u1234", StandardCharsets.UTF_8);
+        final byte[] text = "Hello \u1234".getBytes(StandardCharsets.UTF_8);
         TestUtils.assertEqualContent(text, file);
     }
 
