@@ -143,7 +143,7 @@ public class UnsynchronizedBufferedReaderTest {
 
     @Test
     public void testEmptyInput() throws Exception {
-        try (final UnsynchronizedBufferedReader br = new UnsynchronizedBufferedReader(new StringReader(""))) {
+        try (UnsynchronizedBufferedReader br = new UnsynchronizedBufferedReader(new StringReader(""))) {
             assertEquals(EOF, br.read());
             assertEquals(EOF, br.peek());
             assertNull(br.readLine());
@@ -383,7 +383,8 @@ public class UnsynchronizedBufferedReaderTest {
         assertTrue(new String(buf, 50, 500).equals(testString.substring(0, 500)));
 
         try (UnsynchronizedBufferedReader bufin = new UnsynchronizedBufferedReader(new Reader() {
-            int size = 2, pos = 0;
+            int size = 2;
+            int pos;
 
             char[] contents = new char[size];
 
