@@ -20,25 +20,29 @@ package org.apache.commons.io.serialization;
 
 import java.io.Serializable;
 
+/**
+ * Test fixture for {@link ValidatingObjectInputStreamTest}.
+ */
 public class MockSerializedClass implements Serializable {
+
     private static final long serialVersionUID = 2139985988735372175L;
-    
+
     private final String str;
-    
-    MockSerializedClass(String str) {
+
+    MockSerializedClass(final String str) {
         this.str = str;
     }
 
+    @Override
+    public boolean equals(final Object obj) {
+        if (!(obj instanceof MockSerializedClass)) {
+            return false;
+        }
+        return str.equals(((MockSerializedClass) obj).str);
+    }
+
     @Override
     public int hashCode() {
         return str.hashCode();
     }
-
-    @Override
-    public boolean equals(Object obj) {
-        if(!(obj instanceof MockSerializedClass)) {
-            return false;
-        }
-        return str.equals(((MockSerializedClass)obj).str);
-    }
 }
\ No newline at end of file
